pub enum Observable {
PseudoRange(Frequency),
UnambiguousPhaseRange(Frequency),
Power(Frequency),
Pressure,
Temperature,
HumidityRate,
FrequencyRatio,
}Expand description
Observable describes both frequency and physics. For example, Observable::UnambiguousPhaseRange and Observable::Power are two different physics. DORIS files also provides information sampled at the ground station level for high precision models (like pressure and moisture rate).
Variants
PseudoRange(Frequency)
Decoded Pseudo range (in meters).
All frequency dependent DORIS measurements (=signal measurements) were
performed in space.
UnambiguousPhaseRange(Frequency)
Unambiguous carrier phase observation (in meters, not cycles).
Unlike standard RINEX observations, ambiguities have been resolved
prior publishing a DORIS file.
All frequency dependent DORIS measurements (=signal measurements) were
performed in space.
Power(Frequency)
Received signal power, in [dBm].
All frequency dependent DORIS measurements (=signal measurements) were
performed in space.
Pressure
Pressure at ground station level at epoch of spaceborn observation, in [hPa].
Temperature
Dry temperature at ground station level at epoch of spaceborn observation, in celcius degrees.
HumidityRate
Moisture rate at ground station level at epoch of spaceborn observation, as saturation percentage.
FrequencyRatio
f1 / f2 frequency ratio (dimensionless)
Implementations
Sourceimpl Observable
impl Observable
Sourcepub fn same_frequency(&self, rhs: &Observable) -> bool
pub fn same_frequency(&self, rhs: &Observable) -> bool
Returns true if both Observables come from the same Frequency
Sourcepub fn same_physics(&self, rhs: &Observable) -> bool
pub fn same_physics(&self, rhs: &Observable) -> bool
Returns true if Self and rhs describe the same physical observation. For example, both are phase observations.
Sourcepub fn is_phase_range_observable(&self) -> bool
pub fn is_phase_range_observable(&self) -> bool
Returns true if this a Observable::UnambiguousPhaseRange measurement
Sourcepub fn is_pseudo_range_observable(&self) -> bool
pub fn is_pseudo_range_observable(&self) -> bool
Returns true if this Observable is an Observable::UnambiguousPhaseRange measurement
pub fn is_power_observable(&self) -> bool